<div align="center">
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset="docs/images/libDarkImage.png">
        <img src="./docs/images/libLightImage.png">
    </picture>

![PyPI](https://img.shields.io/pypi/v/ooj)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ooj?color=green&label=downloads)
![Downloads last 6 month](https://static.pepy.tech/personalized-badge/ooj?period=total&units=international_system&left_color=grey&right_color=green&left_text=downloads%20last%206%20month)
![PyPI - License](https://img.shields.io/badge/license-Apache2.0-blue)
</div>

---

The `OOJ` library is a Python package that simplifies working with JSON files. It provides methods to read, write, add, remove, and replace elements in a JSON file.

## Installation

You can install the `OOJ` library directly from PyPI:

### On Windows:
```bash
pip install ooj
```

### On Linux/MacOS:
```bash
pip3 install ooj
```